<?php

namespace SpoonerWeb\BeSecurePw\Tests\Evaluation;

/***************************************************************
 *  Copyright notice
 *
 *  (c) 2010 Thomas Loeffler <loeffler@spooner-web.de>
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *  A copy is found in the textfile GPL.txt and important notices to the license
 *  from the author is found in LICENSE.txt distributed with these scripts.
 *
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

/**
 * Class PasswordEvaluatorTest
 *
 * @package SpoonerWeb\BeSecurePw\Tests\Evaluation
 * @author Thomas Löffler <loeffler@spooner-web.de>
 */
class PasswordEvaluatorTest extends \TYPO3\CMS\Extbase\Tests\Unit\BaseTestCase {

	/**
	 * @var \SpoonerWeb\BeSecurePw\Evaluation\PasswordEvaluator
	 */
	protected $fixture;

	/**
	 * basic setUp method to initialize
	 *
	 * @return void
	 */
	protected function setUp() {
		$this->fixture = new \SpoonerWeb\BeSecurePw\Evaluation\PasswordEvaluator();
	}

	/**
	 * base tearDown method to destroy all attributes at the end
	 *
	 * @return void
	 */
	protected function tearDown() {
		unset($this->fixture);
	}

	/**
	 * @test
	 */
	public function evaluateFieldValueCanBeCalled() {
		$value = 'anyPassword';
		$is_in = '';
		$set = FALSE;

		$this->fixture->evaluateFieldValue($value, $is_in, $set);
	}

	/**
	 * @test
	 */
	public function evaluateFieldValueGivesMd5HashReturnsMd5Hash() {
		$value = md5('anyPassword');
		$is_in = '';
		$set = FALSE;

		$this->assertRegExp(
			'/[0-9abcdef]{32,32}/',
			$this->fixture->evaluateFieldValue($value, $is_in, $set)
		);
	}

	/**
	 * @test
	 */
	public function evaluateFieldValueGivesInvalidPasswordReturnsEmptyString() {
		$value = 'anyPassword';
		$is_in = '';
		$set = FALSE;

		$this->assertSame(
			'',
			$this->fixture->evaluateFieldValue($value, $is_in, $set)
		);
	}

	/**
	 * Test works only with installed and enabled extension saltedpasswords
	 *
	 * @test
	 */
	public function evaluateFieldValueGivesValidPasswordReturnsPassword() {
		if (!\TYPO3\CMS\Core\Utility\ExtensionManagementUtility::isLoaded('saltedpasswords')
			|| !\TYPO3\CMS\Saltedpasswords\Utility\SaltedPasswordsUtility::isUsageEnabled('BE')) {
			$this->markTestSkipped('Test is only for enabled saltedpassword extension');
		}

		$value = 'jikUZ78!j?';
		$is_in = '';
		$set = FALSE;

		$this->assertSame(
			$value,
			$this->fixture->evaluateFieldValue($value, $is_in, $set)
		);
	}

	/**
	 * Test works only with disabled or uninstalled extension saltedpasswords
	 *
	 * @test
	 */
	public function evaluateFieldValueGivesValidPasswordReturnsMd5HashedPassword() {
		if (\TYPO3\CMS\Core\Utility\ExtensionManagementUtility::isLoaded('saltedpasswords')
			&& \TYPO3\CMS\Saltedpasswords\Utility\SaltedPasswordsUtility::isUsageEnabled('BE')) {
			$this->markTestSkipped('Test is only for environments without installed saltedpasswords extension');
		}

		$value = 'jikUZ78!j?';
		$is_in = '';
		$set = FALSE;

		$this->assertSame(
			md5($value),
			$this->fixture->evaluateFieldValue($value, $is_in, $set)
		);
	}
}